@@ -170,7 +170,7 @@ class ImportCellParser:
         if cellobject.value is None:
             return None
         if not isinstance(cellobject.value, str):
-            raise ImportCellParserException((f"IQF004TASKOWNERS: Cell contents type is {type(_value)}, "
+            raise ImportCellParserException((f"IQF004TASKOWNERS: Cell contents type is {type(cellobject.value)}, "
                                              f"string type required"))
         return self._parsenames(cellobject, ";")
 
