@@ -4,11 +4,12 @@
 
 Generic ViledaUtils class implementing static methods to use for MS Excel import / export and API communication
 """
+
 import logging
 from datetime import datetime, timedelta
 from os import walk
 from traceback import format_exc
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Optional
 
 from openpyxl import load_workbook
 
@@ -22,7 +23,7 @@ class ViledaUtils:
     """
 
     @staticmethod
-    def loadexcels(xlsdir: str, tolog: logging.Logger) -> List[Dict[str, Any]]:
+    def loadexcels(xlsdir: str, tolog: logging.Logger, pfile: Optional[str] = None) -> List[Dict[str, Any]]:
         """
         Loads all excels from given folder, parses all records in all sheets, and returns a list of dicts representing
         records found in sheets. From sheet to sheet records can contain different sets of fields, which is allowed.
@@ -31,17 +32,25 @@ class ViledaUtils:
 
         :param xlsdir: path to directory with MS Excel *.xlsx workbooks
         :param tolog: logger object to use
+        :param pfile: file to record import progress, one single file created, by default is "progress" in the
+                      same xlsdir folder, or full path/filename can be specified explicitly by this parameter
         :return: list of task records loaded from excel sheets
         """
         # List of workbooks
         wbs = dict()
+        # Name of progress record file - it must be ignored by the import
+        if pfile is None:
+            _pfile = "progress"
+        else:
+            _pfile = pfile
         # Load all files from folder
         _log_wbs_list = list()
         for _tmp_root, _tmp_dirs, _tmp_files in walk(xlsdir):
             for _tmp_name_walk_f in _tmp_files:
                 try:
-                    wbs[_tmp_name_walk_f] = load_workbook(filename=f"{xlsdir.strip('/')}/{_tmp_name_walk_f}")
-                    _log_wbs_list.append(_tmp_name_walk_f)
+                    if _tmp_name_walk_f != _pfile:
+                        wbs[_tmp_name_walk_f] = load_workbook(filename=f"{xlsdir.strip('/')}/{_tmp_name_walk_f}")
+                        _log_wbs_list.append(_tmp_name_walk_f)
                 except Exception:
                     tolog.warning(f"Can't load {xlsdir.strip('/')}/{_tmp_name_walk_f}:\n{format_exc()}")
         # Log loaded workbooks
@@ -67,7 +76,9 @@ class ViledaUtils:
                     _sheet_parser = ImportSheetParser(_w[_sname], _sname)
                     if not _sheet_parser.ok():
                         raise ImportSheetParserException(f"      ERROR: failed loading sheet '{_sname}'")
-                    reclist += _sheet_parser.getparsedrecords()
+                    _parsed_records = _sheet_parser.getparsedrecords()
+                    for _r in _parsed_records:
+                        reclist += {**_r, "_wname": _wname, "_sname": _sname}
                     _log_str_loading += _sheet_parser.getlog()
                     _log_str_loading += (f"      TOTAL:  parsed records {_sheet_parser.getpasrsestats()['OK']} "
                                          f"of {_sheet_parser.getpasrsestats()['TOTAL']}\n")
